==> istio-model-v1alpha3-6.8.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterListenerMatchFilterChainMatchFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterListenerMatchFilterChainMatchFluent<A extends EnvoyFilterListenerMatchFilterChainMatchFluent<A>> extends BaseFluent<A>{
  public EnvoyFilterListenerMatchFilterChainMatchFluent() {
  }
  public EnvoyFilterListenerMatchFilterChainMatchFluent(EnvoyFilterListenerMatchFilterChainMatch instance) {
    instance = (instance != null ? instance : new EnvoyFilterListenerMatchFilterChainMatch());

    if (instance != null) {
      this.withApplicationProtocols(instance.getApplicationProtocols());
      this.withDestinationPort(instance.getDestinationPort());
      this.withFilter(instance.getFilter());
      this.withName(instance.getName());
      this.withSni(instance.getSni());
      this.withTransportProtocol(instance.getTransportProtocol());
      this.withApplicationProtocols(instance.getApplicationProtocols());
      this.withDestinationPort(instance.getDestinationPort());
      this.withFilter(instance.getFilter());
      this.withName(instance.getName());
      this.withSni(instance.getSni());
      this.withTransportProtocol(instance.getTransportProtocol());
    }
  }
  private String applicationProtocols;
  private Integer destinationPort;
  private EnvoyFilterListenerMatchFilterMatchBuilder filter;
  private String name;
  private String sni;
  private String transportProtocol;
  public String getApplicationProtocols() {
    return this.applicationProtocols;
  }
  public A withApplicationProtocols(String applicationProtocols) {
    this.applicationProtocols=applicationProtocols; return (A) this;
  }
  public boolean hasApplicationProtocols() {
    return this.applicationProtocols != null;
  }
  public Integer getDestinationPort() {
    return this.destinationPort;
  }
  public A withDestinationPort(Integer destinationPort) {
    this.destinationPort=destinationPort; return (A) this;
  }
  public boolean hasDestinationPort() {
    return this.destinationPort != null;
  }
  public EnvoyFilterListenerMatchFilterMatch buildFilter() {
    return this.filter!=null ?this.filter.build():null;
  }
  public A withFilter(EnvoyFilterListenerMatchFilterMatch filter) {
    _visitables.get("filter").remove(this.filter);
    if (filter!=null){ this.filter= new EnvoyFilterListenerMatchFilterMatchBuilder(filter); _visitables.get("filter").add(this.filter);} else { this.filter = null; _visitables.get("filter").remove(this.filter); } return (A) this;
  }
  public boolean hasFilter() {
    return this.filter != null;
  }
  public FilterNested<A> withNewFilter() {
    return new FilterNested(null);
  }
  public FilterNested<A> withNewFilterLike(EnvoyFilterListenerMatchFilterMatch item) {
    return new FilterNested(item);
  }
  public FilterNested<A> editFilter() {
    return withNewFilterLike(java.util.Optional.ofNullable(buildFilter()).orElse(null));
  }
  public FilterNested<A> editOrNewFilter() {
    return withNewFilterLike(java.util.Optional.ofNullable(buildFilter()).orElse(new EnvoyFilterListenerMatchFilterMatchBuilder().build()));
  }
  public FilterNested<A> editOrNewFilterLike(EnvoyFilterListenerMatchFilterMatch item) {
    return withNewFilterLike(java.util.Optional.ofNullable(buildFilter()).orElse(item));
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public boolean hasName() {
    return this.name != null;
  }
  public String getSni() {
    return this.sni;
  }
  public A withSni(String sni) {
    this.sni=sni; return (A) this;
  }
  public boolean hasSni() {
    return this.sni != null;
  }
  public String getTransportProtocol() {
    return this.transportProtocol;
  }
  public A withTransportProtocol(String transportProtocol) {
    this.transportProtocol=transportProtocol; return (A) this;
  }
  public boolean hasTransportProtocol() {
    return this.transportProtocol != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterListenerMatchFilterChainMatchFluent that = (EnvoyFilterListenerMatchFilterChainMatchFluent) o;
    if (!java.util.Objects.equals(applicationProtocols, that.applicationProtocols)) return false;

    if (!java.util.Objects.equals(destinationPort, that.destinationPort)) return false;

    if (!java.util.Objects.equals(filter, that.filter)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(sni, that.sni)) return false;

    if (!java.util.Objects.equals(transportProtocol, that.transportProtocol)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(applicationProtocols,  destinationPort,  filter,  name,  sni,  transportProtocol,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (applicationProtocols != null) { sb.append("applicationProtocols:"); sb.append(applicationProtocols + ","); }
    if (destinationPort != null) { sb.append("destinationPort:"); sb.append(destinationPort + ","); }
    if (filter != null) { sb.append("filter:"); sb.append(filter + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (sni != null) { sb.append("sni:"); sb.append(sni + ","); }
    if (transportProtocol != null) { sb.append("transportProtocol:"); sb.append(transportProtocol); }
    sb.append("}");
    return sb.toString();
  }
  public class FilterNested<N> extends EnvoyFilterListenerMatchFilterMatchFluent<FilterNested<N>> implements Nested<N>{
    FilterNested(EnvoyFilterListenerMatchFilterMatch item) {
      this.builder = new EnvoyFilterListenerMatchFilterMatchBuilder(this, item);
    }
    EnvoyFilterListenerMatchFilterMatchBuilder builder;
    public N and() {
      return (N) EnvoyFilterListenerMatchFilterChainMatchFluent.this.withFilter(builder.build());
    }
    public N endFilter() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterListenerMatchFilterChainMatchFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class EnvoyFilterListenerMatchFilterChainMatchFluent<A extends EnvoyFilterListenerMatchFilterChainMatchFluent<A>> extends BaseFluent<A>{
  public EnvoyFilterListenerMatchFilterChainMatchFluent() {
  }
  
  public EnvoyFilterListenerMatchFilterChainMatchFluent(EnvoyFilterListenerMatchFilterChainMatch instance) {
    this.copyInstance(instance);
  }
  private String applicationProtocols;
  private Integer destinationPort;
  private EnvoyFilterListenerMatchFilterMatchBuilder filter;
  private String name;
  private String sni;
  private String transportProtocol;
  
  protected void copyInstance(EnvoyFilterListenerMatchFilterChainMatch instance) {
    instance = (instance != null ? instance : new EnvoyFilterListenerMatchFilterChainMatch());
  
    if (instance != null) {
        this.withApplicationProtocols(instance.getApplicationProtocols());
        this.withDestinationPort(instance.getDestinationPort());
        this.withFilter(instance.getFilter());
        this.withName(instance.getName());
        this.withSni(instance.getSni());
        this.withTransportProtocol(instance.getTransportProtocol());
        this.withApplicationProtocols(instance.getApplicationProtocols());
        this.withDestinationPort(instance.getDestinationPort());
        this.withFilter(instance.getFilter());
        this.withName(instance.getName());
        this.withSni(instance.getSni());
        this.withTransportProtocol(instance.getTransportProtocol());
      }
  }
  
  public String getApplicationProtocols() {
    return this.applicationProtocols;
  }
  
  public A withApplicationProtocols(String applicationProtocols) {
    this.applicationProtocols=applicationProtocols; return (A) this;
  }
  
  public boolean hasApplicationProtocols() {
    return this.applicationProtocols != null;
  }
  
  public Integer getDestinationPort() {
    return this.destinationPort;
  }
  
  public A withDestinationPort(Integer destinationPort) {
    this.destinationPort=destinationPort; return (A) this;
  }
  
  public boolean hasDestinationPort() {
    return this.destinationPort != null;
  }
  
  public EnvoyFilterListenerMatchFilterMatch buildFilter() {
    return this.filter!=null ?this.filter.build():null;
  }
  
  public A withFilter(EnvoyFilterListenerMatchFilterMatch filter) {
    _visitables.get("filter").remove(this.filter);
    if (filter!=null){ this.filter= new EnvoyFilterListenerMatchFilterMatchBuilder(filter); _visitables.get("filter").add(this.filter);} else { this.filter = null; _visitables.get("filter").remove(this.filter); } return (A) this;
  }
  
  public boolean hasFilter() {
    return this.filter != null;
  }
  
  public FilterNested<A> withNewFilter() {
    return new FilterNested(null);
  }
  
  public FilterNested<A> withNewFilterLike(EnvoyFilterListenerMatchFilterMatch item) {
    return new FilterNested(item);
  }
  
  public FilterNested<A> editFilter() {
    return withNewFilterLike(java.util.Optional.ofNullable(buildFilter()).orElse(null));
  }
  
  public FilterNested<A> editOrNewFilter() {
    return withNewFilterLike(java.util.Optional.ofNullable(buildFilter()).orElse(new EnvoyFilterListenerMatchFilterMatchBuilder().build()));
  }
  
  public FilterNested<A> editOrNewFilterLike(EnvoyFilterListenerMatchFilterMatch item) {
    return withNewFilterLike(java.util.Optional.ofNullable(buildFilter()).orElse(item));
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public String getSni() {
    return this.sni;
  }
  
  public A withSni(String sni) {
    this.sni=sni; return (A) this;
  }
  
  public boolean hasSni() {
    return this.sni != null;
  }
  
  public String getTransportProtocol() {
    return this.transportProtocol;
  }
  
  public A withTransportProtocol(String transportProtocol) {
    this.transportProtocol=transportProtocol; return (A) this;
  }
  
  public boolean hasTransportProtocol() {
    return this.transportProtocol != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterListenerMatchFilterChainMatchFluent that = (EnvoyFilterListenerMatchFilterChainMatchFluent) o;
    if (!java.util.Objects.equals(applicationProtocols, that.applicationProtocols)) return false;
  
    if (!java.util.Objects.equals(destinationPort, that.destinationPort)) return false;
  
    if (!java.util.Objects.equals(filter, that.filter)) return false;
  
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    if (!java.util.Objects.equals(sni, that.sni)) return false;
  
    if (!java.util.Objects.equals(transportProtocol, that.transportProtocol)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(applicationProtocols,  destinationPort,  filter,  name,  sni,  transportProtocol,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (applicationProtocols != null) { sb.append("applicationProtocols:"); sb.append(applicationProtocols + ","); }
    if (destinationPort != null) { sb.append("destinationPort:"); sb.append(destinationPort + ","); }
    if (filter != null) { sb.append("filter:"); sb.append(filter + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (sni != null) { sb.append("sni:"); sb.append(sni + ","); }
    if (transportProtocol != null) { sb.append("transportProtocol:"); sb.append(transportProtocol); }
    sb.append("}");
    return sb.toString();
  }
  public class FilterNested<N> extends EnvoyFilterListenerMatchFilterMatchFluent<FilterNested<N>> implements Nested<N>{
    FilterNested(EnvoyFilterListenerMatchFilterMatch item) {
      this.builder = new EnvoyFilterListenerMatchFilterMatchBuilder(this, item);
    }
    EnvoyFilterListenerMatchFilterMatchBuilder builder;
    
    public N and() {
      return (N) EnvoyFilterListenerMatchFilterChainMatchFluent.this.withFilter(builder.build());
    }
    
    public N endFilter() {
      return and();
    }
    
  
  }

}
